#
# spec file for package gnu-free-fonts
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define fontname freefont
%define fontversion 20120503
%define _ttfontsdir %{_datadir}/fonts/truetype
Name:           gnu-free-fonts
Version:        0.%{fontversion}
Release:        11.2
Summary:        Free UCS Outline Fonts
License:        SUSE-GPL-3.0+-with-font-exception
Group:          System/X11/Fonts
Url:            http://savannah.nongnu.org/projects/freefont/
Source0:        http://ftp.gnu.org/gnu/freefont/%{fontname}-src-%{fontversion}.tar.gz
Source10:       remove-kana-glyphs
Source11:       GenerateTrueType
# PATCH-FIX-UPSTREAM -- bmwiedemann fix build-compare https://savannah.gnu.org/bugs/index.php?47722
Patch0:         reproducible.patch
Patch1:         freefont-build-using-py3.patch
# PATCH-FIX-UPSTREAM -- https://savannah.gnu.org/bugs/index.php?47634
Patch2:         make_ff_version_check_forward_compatible.patch
BuildRequires:  fontforge >= 20080429
BuildRequires:  fontpackages-devel
BuildRequires:  python3-base
# freefont was last used at openSUSE 12.1 (version 0.20110523)
Obsoletes:      %{fontname} < %{version}
Provides:       %{fontname} = %{version}
Provides:       scalable-font-bg
Provides:       scalable-font-el
Provides:       scalable-font-he
Provides:       scalable-font-ru
Provides:       locale(bg;el;he;ru;vi)
BuildArch:      noarch
%reconfigure_fonts_prereq

%description
A set of free outline (OpenType, for example) fonts covering the ISO
10646/Unicode UCS (Universal Character Set). The set consists of three
typefaces: one monospaced and two proportional (one with uniform and
one with modulated stroke).

%prep
%autosetup -p1 -n %{fontname}-%{fontversion}

%build
chmod 755 $RPM_SOURCE_DIR/remove-kana-glyphs
$RPM_SOURCE_DIR/remove-kana-glyphs ./sfd/*.sfd
make %{?_smp_mflags} ttf

%install
mkdir -p %{buildroot}%{_ttfontsdir}/
install -pm 0644 sfd/*.ttf %{buildroot}%{_ttfontsdir}/

%reconfigure_fonts_scriptlets

%files
%license COPYING
%doc AUTHORS CREDITS ChangeLog README notes/troubleshooting.txt notes/usage.txt
%{_ttfontsdir}

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sun Sep  1 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix building with fontforge 20190801
  Add make_ff_version_check_forward_compatible.patch
- Use license for COPYING
* Thu Jan 11 2018 tchvatal@suse.com
- Format with spec-cleaner
- Drop sle11 support as we use just py3
- Drop the BR on python in favor of python3-base
* Tue Jan  9 2018 dimstar@opensuse.org
- Add freefont-build-using-py3.patch: Fix build when using python3.
* Sun Apr 17 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Thu Aug  2 2012 asterios.dramis@gmail.com
- Update to version 0.20120503:
  * Lots of changes (see http://savannah.gnu.org/forum/forum.php?forum_id=7216
    and ChangeLog for details).
- Use the package scripts for generating the fonts in openSUSE > 11.2. Use the
  "GenerateTrueType" external script only for older versions (package fails to
  compile otherwise).
* Wed Jul  4 2012 pgajdos@suse.cz
- amend spec file to reflect new font packaging scheme
  (see openFATE#313536);
* Thu May 17 2012 pgajdos@suse.com
- call spec-cleaner
* Wed Mar 14 2012 cfarrell@suse.com
- license update: SUSE-GPL-3.0+-with-font-exception
  There are GPL-3.0 licensed fonts - also, use SUSE- proprietary prefix
  until license is accepted upstream at spdx.org
* Wed Dec 21 2011 toms@suse.de
- Renamed freefont -> gnu-free-fonts according to
  openSUSE packaging guidelines and FATE#313035
  Adjusted Obsoletes and Provides accordingly
* Tue Nov  1 2011 pgajdos@suse.com
- freefont changed to svn:
  svn co svn://svn.savannah.gnu.org/freefont/trunk/freefont
- updated to 0.20111101:
  * Cyrillic: added 'locl' lookup for Serbian/Macedonian 'be'
  * Latin, Diacritics, etc: hungarian umlaut, double grave adjustments
  * Latin: small adjustment to letter spacing
  * Latin: much messing with accents for Vietnamese, some kerning
  * etc. see svn changelog
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Sat Aug 13 2011 andrea.turrini@gmail.com
- fixed typo in freefont.spec
* Mon May 23 2011 pgajdos@novell.com
- updated to 20110523
* Thu Nov 18 2010 pgajdos@suse.cz
- updated to 0.20101118
* Thu Apr  8 2010 tiwai@suse.de
- fix build with new fontforge
- minor clean-ups
* Tue Dec  8 2009 pgajdos@suse.cz
- updated to 0.20091208
- used old but working GenerateTrueType script
* Mon May 26 2008 mfabian@suse.de
- bnc#246804: update to latest release (0.20080323), this seems
  to finally fix the spacing issues in the monospace font.
* Tue Aug  8 2006 mfabian@suse.de
- BuildRequires: xorg-x11-devel is necessary to detect Xorg X11R7.
* Mon Aug  7 2006 mfabian@suse.de
- move fonts to /usr/share/fonts because of the move to Xorg X11R7.
* Fri Aug  4 2006 mfabian@suse.de
- remove "#!BuildIgnore: NX". It is not necessary anymore, on
  the contrary it makes the build fail now for xorg7-SUSE_Factory
  in the openSUSE build service.
* Thu Jul 20 2006 mfabian@suse.de
- add "chmod 755 $RPM_SOURCE_DIR/remove-kana-glyphs" to make
  it build in the openSUSE build service.
  Permissions for any file in $RPM_SOURCE_DIR are nowhere guaranteed
  to be preserved.
* Tue Jul 18 2006 mfabian@suse.de
- add "#!BuildIgnore: NX" to make it build for the
  xorg7-SUSE_Factory in the openSUSE build service.
- add "vi" to the "Provides: locale".
* Tue Jul 18 2006 mfabian@suse.de
- update to 0.20060718.
  + All the fonts now conform to MES-1 (Minimum European Subset) of
    Unicode/ISO 10646. In addition, thanks to Solaiman Karim,
    Omi Azad, K.H. Hussain and R. Chitrajan, OpenType support for
    Bengali (in FreeSerif, FreeSerifItalic, FreeSans and
    FreeSansOblique) and traditional Malayalam (FreeSerif) might
    be mentioned as major new features.
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(bg;el;he;ru)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  3 2004 mfabian@suse.de
- use new macro "%%run_suseconfig_fonts".
* Mon Sep 13 2004 mfabian@suse.de
- Bugzilla #45156: add "Provides:     scalable-font-el,
  scalable-font-he, scalable-font-ru, scalable-font-bg".
* Thu Aug 19 2004 ro@suse.de
- PfaEdit has been renamed to fontforge
* Sat Apr 24 2004 sndirsch@suse.de
- fixed neededforbuild (XFree86-libs --> xorg-x11-libs)
* Thu Apr  1 2004 mfabian@suse.de
- Bugzilla #37113: remove Kana to improve the appearance of
  Japanese during the installation.
  Kana without Kanji are completely useless.
  They can only cause problems because it can happen
  that they are combined with Kanji from a completely different
  font which looks very ugly. This happens easily in Qt
  applications because Qt unfortunately treats "Hiragana",
  "Katakana", and "Han" as 3 different Unicode regions and may
  select a different font for each of these regions. I.e. if
  FreeSans is set as the main font in Qt while using Japanese,
  FreeSans will be used no only for Latin but also for Kana and
  only for the Kanji a "real" Japanese font like "Kochi Gothic"
  will be used. This looks very bad. If FreeSans doesn't have
  Kana at all, the "real" Japanese font will be used for the
  Kana and the Kanji, which looks much nicer.
* Thu Mar 18 2004 mfabian@suse.de
- use %%suseconfig_fonts_prereq
* Fri Feb 27 2004 mfabian@suse.de
- update to 0.20040227.
- run SuSEconfig.fonts and SuSEconfig.pango in %%post and %%postun
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Sun Sep 14 2003 mfabian@suse.de
- Bugzilla #30768: update to version 0.20030914 which includes
  the U+30FC KATAKANA-HIRAGANA PROLONGED SOUND MARK glyph missing
  in previous versions.
* Mon Aug 18 2003 mfabian@suse.de
- new package, version 0.20030815
